@@ -1,7 +1,7 @@
 library(diveMove)
 
-zz <- gzfile(system.file(file.path("data", "dives.csv.gz"),
-                         package="diveMove"), open="r")
+zz <- system.file(file.path("data", "dives.csv"),
+                  package="diveMove")
 (sealX <- readTDR(zz, concurrentCols=4:6, sep=";",
                   na.strings="", as.is=TRUE))
 (dcalib <- calibrateDepth(sealX, zoc.method="offset", offset=3))
@@ -11,8 +11,8 @@ head(stamps <- stampDive(dcalib))
 (att <- timeBudget(dcalib, FALSE))
 (att <- timeBudget(dcalib, TRUE))
 
-zz <- gzfile(system.file(file.path("data", "dives.csv.gz"),
-                         package="diveMove"), open="r")
+zz <- system.file(file.path("data", "dives.csv"),
+                  package="diveMove")
 (sealX <- readTDR(zz, speed=TRUE, concurrentCols=4:6,
                   sep=";", na.strings="", as.is=TRUE))
 (dcalib <- calibrateDepth(sealX, zoc.method="offset", offset=3))
